==> FHLBBS-5.3.tgz: php/mlist.php <==
<?php
 require("config.php");
 require("wbbs.php");
 require("auth.php");
 session_register("userid","cuser","mail_pt","delflag");

   $prcolor = 1;
   $defaultColor = "#FFFFFF";

   $genbuf=$QUERY_STRING;

   if(strstr($genbuf,"delete")!==false)
      if ($delflag==1) $delflag=0;
      else $delflag=1;
   //else
   //   $delflag=0;
    /** Bz}l   **/
   if($foo = strrchr($genbuf, '$')){
        if (strstr($genbuf,"top")!==false) $querymode=1;
        else if (strstr($genbuf,"pgup")!==false) $querymode=2;
        else if (strstr($genbuf,"pgdn")!==false) $querymode=3;
        else if (strstr($genbuf,"bottom")!==false) $querymode=4;
        else
        {
          $start = (int) substr($foo,1);
          $querymode=0;
        }
        $genbuf=strtok($genbuf,"$"); //oJboardname
   } // if has $num $top $bottom $pgup $pgdn
   else $querymode=4;

   if ($start==0) $start=$mail_pt;

   if (strrchr($genbuf,'/')!==false) //ȬOhacker
	 die ("<h1>AOhackerܡH</h1><p>\n");
  
   $curr_board="mail";
   $path1=sethomedir($cuser->userid);
   if (is_file($path1))
   	$numposts = filesize($path1)/$dirlength;
   else
	$numposts = 0;

   if ($querymode==2)
	$start=($mail_pt-$SHOWNUM > 0) ? ($mail_pt-$SHOWNUM) : 1;
   elseif ($querymode==3) 
        $start=($mail_pt+$SHOWNUM < $numposts-$SHOWNUM) ? ($mail_pt+$SHOWNUM) : $numposts-$SHOWNUM;
   elseif ($querymode==1) $start=1;
   elseif ($querymode==4) $start= $numposts-$SHOWNUM;

   if($start == 999999)
	  $start = ($numposts - $SHOWNUM > 0) ? ($numposts - $SHOWNUM) : 1;
   elseif($start <= 0)
	  $start = 1;

   $mail_pt=$start;
  
    /* o٭n@UA]nҼ{O_vAHΨCӪDiHק  */
   if($delflag==0)  
	$buf2=$DEFDIR[$doorid].$MLISTDEF;
   else
	$buf2=$DEFDIR[$doorid].$MDELDEF;

   if( ($fp = fopen($buf2,"r")) ===false  )
       die ("{$buf2}ɮ׶}ҿ~<br>");
    /*}lBz榡 ****/
    while (!feof($fp))
    {
        $genbuf=fgets($fp,1000);
        $pt1=$genbuf;
        while (!(($pt2=strpos($pt1,"<!--$"))===false))
        {
           $bpt2=substr($pt1,0,$pt2);
           echo "$bpt2";/* LXtokener */
           $pt1=substr($pt1,$pt2+5);
           $ptmode=(int) $pt1;//নƦr
           $pt3=strpos($pt1,"-->");
           if ($pt3===false)
                        die ("榡ɿ~IP@椺䤣 -->");
            $pt1=substr($pt1,$pt3+3);
            if ($ptmode>0)   SSI($ptmode);
            else
            {
		$color=$pt1;
                $pt3=strpos($color,"#end");
                if ($pt3 === false) // 䤣wqColorŸ#end
                        $color = $defaultColor;
                else {
                        $color=substr($color,0,7);
                        $pt1=substr($pt1,$pt3+4);
                }
            	echo "<table>";
                if($delflag==1)
                   echo "<tr><td>R</td><td>s</td><td>Ū</td><td>@</td><td></td><td>D</td></tr>\n";
                else
                   echo "<tr><td>s</td><td>Ū</td><td>@</td><td></td><td>D</td></tr>\n";
             /* Ū .DIR  */
   		$buf1=sethomedir($cuser->userid);
                if(is_file($buf1) &&  ($fd = fopen( $buf1, "r" )) !== false )
                {
             	   fseek($fd, $dirlength * ($start-1), SEEK_SET);
                   $end1 = ($start + $SHOWNUM > $numposts) ? $numposts : 
                           ($start + $SHOWNUM);
                   $showcnt=0;
		   $postfile=new dirrec;
                   for($j = $start;$j <= $end1;$j++) 
                   {
                     $genbuf=fread($fd,$dirlength);
		     $postfile->unpack($genbuf);
                     $buf1 = $postfile->date;
		     if ($prcolor==1) $prcolor=0;
		     else $prcolor=1;
                     if ($delflag==1){
                          $showcnt++;
		          if ($prcolor==1) {  // Praise Modify 4/21/2001
			     $genbuf=sprintf("<tr><td bgcolor=%s><input name=\"m%d\" type=checkbox value=\"%d\"></td><td bgcolor=%s>%3d.</td><td bgcolor=%s>%s</td><td bgcolor=%s>%-15s</td><td bgcolor=%s>%-5s</td>\n"
                             ,$color,$showcnt,$j,$color,$j,$color, ($postfile->filemode&$FILE_READ)?"":""
		             ,$color,$postfile->owner, $color, $buf1);
		             echo $genbuf;
		          } 
		          else { 
                             $genbuf=sprintf("<tr><td><input name=\"m%d\" type=checkbox value=\"%d\"></td><td>%3d.</td><td>%s</td><td>%-15s</td><td>%-5s</td>\n"
                             ,$showcnt,$j,$j, ($postfile->filemode&$FILE_READ)?"":"",$postfile->owner,$buf1);
		    	     echo $genbuf;
		          }
                     } //delflag==1
                     else{
		          if ($prcolor==1) {
                             $genbuf=sprintf("<tr><td bgcolor = %s>%3d.</td><td bgcolor = %s>%s</td><td bgcolor = %s>%-15s</td><td bgcolor=%s>%-5s</td>"
                     	     ,$color, $j, $color, ($postfile->filemode&$FILE_READ)?"":"",
			      $color,	$postfile->owner, $color, $buf1);
			     echo $genbuf;
		          }
		          else {
                             $genbuf=sprintf("<tr><td>%3d.</td><td>%s</td><td>%-15s</td><td>%-5s</td>"
                             ,$j, ($postfile->filemode&$FILE_READ)?"":"",$postfile->owner,$buf1);
			     echo $genbuf;
		          }
                     } //delflag==0
		     if ($prcolor==1) {
		     	$genbuf=sprintf("<td bgcolor = %s><a href=\"read.php?%s$%d\">%s</a><td bgcolor = %s><tr>\n"
			, $color,$curr_board, $j, strlen($postfile->title)?$postfile->title:"LD", $color);
			echo $genbuf;
		     }
		     else {
               		$genbuf=sprintf("<td><a href=\"read.php?%s$%d\">%s</a><td><tr>\n"
			, $curr_board, $j,  strlen($postfile->title)?$postfile->title:"LD");
			echo $genbuf;
		     }
             } //for j
	         echo "</table>";

             fclose($fd);
             }/* endif(fd) */
             else
                die("SHI");
         }
       } // while pt1
     echo  $pt1;
   } //while get oneline
      fclose($fp);
?>

==> FHLBBS-5.4.tgz: php/mlist.php <==
<?php
 require("config.php");
 require("wbbs.php");
 require("auth.php");
 session_register("userid","cuser","mail_pt","delflag");


   $genbuf=$QUERY_STRING;

   if(strstr($genbuf,"delete")!==false)
      if ($delflag==1) $delflag=0;
      else $delflag=1;
   //else
   //   $delflag=0;
    /** Bz}l   **/
   if($foo = strrchr($genbuf, '$')){
        if (strstr($genbuf,"top")!==false) $querymode=1;
        else if (strstr($genbuf,"pgup")!==false) $querymode=2;
        else if (strstr($genbuf,"pgdn")!==false) $querymode=3;
        else if (strstr($genbuf,"bottom")!==false) $querymode=4;
        else
        {
          $start = (int) substr($foo,1);
          $querymode=0;
        }
        $genbuf=strtok($genbuf,"$"); //oJboardname
   } // if has $num $top $bottom $pgup $pgdn
   else $querymode=4;

   if ($start==0) $start=$mail_pt;

   if (strrchr($genbuf,'/')!==false) //ȬOhacker
	 die ("<h1>AOhackerܡH</h1><p>\n");
  
   $curr_board="mail";
   $path1=sethomedir($cuser->userid);
   if (is_file($path1))
   	$numposts = filesize($path1)/$dirlength;
   else
	$numposts = 0;

   if ($querymode==2)
	$start=($mail_pt-$SHOWNUM > 0) ? ($mail_pt-$SHOWNUM) : 1;
   elseif ($querymode==3) 
        $start=($mail_pt+$SHOWNUM < $numposts-$SHOWNUM) ? ($mail_pt+$SHOWNUM) : $numposts-$SHOWNUM;
   elseif ($querymode==1) $start=1;
   elseif ($querymode==4) $start= $numposts-$SHOWNUM;

   if($start == 999999)
	  $start = ($numposts - $SHOWNUM > 0) ? ($numposts - $SHOWNUM) : 1;
   elseif($start <= 0)
	  $start = 1;

   $mail_pt=$start;
  
    /* o٭n@UA]nҼ{O_vAHΨCӪDiHק  */
   if($delflag==0)  
	$buf2=$DEFDIR[$doorid].$MLISTDEF;
   else
	$buf2=$DEFDIR[$doorid].$MDELDEF;

   if( ($fp = fopen($buf2,"r")) ===false  )
       die ("{$buf2}ɮ׶}ҿ~<br>");
    /*}lBz榡 ****/
    while (!feof($fp))
    {
        $genbuf=fgets($fp,1000);
        $pt1=$genbuf;
        while (!(($pt2=strpos($pt1,"<!--$"))===false))
        {
           $bpt2=substr($pt1,0,$pt2);
           echo "$bpt2";/* LXtokener */
           $pt1=substr($pt1,$pt2+5);
           $ptmode=(int) $pt1;//নƦr
           $pt3=strpos($pt1,"-->");
           if ($pt3===false)
                        die ("榡ɿ~IP@椺䤣 -->");
            $pt1=substr($pt1,$pt3+3);
            if ($ptmode>0)   SSI($ptmode);
            else
            {
		/***************************
		$color=$pt1;
                $pt3=strpos($color,"#end");
                if ($pt3 === false) // 䤣wqColorŸ#end
                        $color = $defaultColor;
                else {
                        $color=substr($color,0,7);
                        $pt1=substr($pt1,$pt3+4);
                }
                ************************************/
            	echo "<table>";
                if($delflag==1)
                   echo "<tr><td>R</td><td>s</td><td>Ū</td><td>@</td><td></td><td>D</td></tr>\n";
                else
                   echo "<tr><td>s</td><td>Ū</td><td>@</td><td></td><td>D</td></tr>\n";
             /* Ū .DIR  */
   		$buf1=sethomedir($cuser->userid);
                if(is_file($buf1) &&  ($fd = fopen( $buf1, "r" )) !== false )
                {
             	   fseek($fd, $dirlength * ($start-1), SEEK_SET);
                   $end1 = ($start + $SHOWNUM > $numposts) ? $numposts : 
                           ($start + $SHOWNUM);
                   $showcnt=0;
		   $postfile=new dirrec;
                   for($j = $start;$j <= $end1;$j++) 
                   {
		     $cj=$j%2;
                     $genbuf=fread($fd,$dirlength);
		     $postfile->unpack($genbuf);
                     $buf1 = $postfile->date;
                     if ($delflag==1){
                          $showcnt++;
			     $genbuf=sprintf("<tr><td{$tcolor[$cj]}><input name=\"m%d\" type=checkbox value=\"%d\"></td><td{$tcolor[$cj]}>%3d.</td><td{$tcolor[$cj]}>%s</td><td{$tcolor[$cj]}>%-15s</td><td{$tcolor[$cj]}>%-5s</td>\n"
                             ,$showcnt,$j,$j,($postfile->filemode&$FILE_READ)?"":""
		             ,$postfile->owner, $buf1);
		             echo $genbuf;
                     } //delflag==1
                     else{
                             $genbuf=sprintf("<tr><td{$tcolor[$cj]}>%3d.</td><td{$tcolor[$cj]}>%s</td><td{$tcolor[$cj]}>%-15s</td><td{$tcolor[$cj]}>%-5s</td>"
                     	     ,$j, ($postfile->filemode&$FILE_READ)?"":"",
			      $postfile->owner, $buf1);
			     echo $genbuf;
                     } //delflag==0
		     	$genbuf=sprintf("<td{$tcolor[$cj]}><a href=\"read.php?%s$%d\">%s</a><td{$tcolor[$cj]}><tr>\n"
			,$curr_board, $j, strlen($postfile->title)?$postfile->title:"LD");
			echo $genbuf;
             } //for j
	         echo "</table>";

             fclose($fd);
             }/* endif(fd) */
             else
                die("SHI");
         }
       } // while pt1
     echo  $pt1;
   } //while get oneline
      fclose($fp);
?>
